@@ -12,7 +12,7 @@ import json
 import os
 import random
 import re
-from typing import Union, Optional, Type
+from typing import Union, Optional
 
 import httpx
 import nonebot
@@ -35,6 +35,7 @@ su = global_config.superusers
 cb_notice = plugin_config.callback_notice
 
 
+
 def At(data: str) -> Union[list[str], list[int], list]:
     """
     检测at了谁，返回[qq, qq, qq,...]
@@ -110,37 +111,39 @@ async def init():
     :return:
     """
     for d in dirs:
-        if not os.path.exists(d):
+        if not d.exists():
             await mk('dir', d, mode=None)
-    if not os.path.exists(config_admin):
+    if not config_admin.exists():
         await mk('file', config_admin, 'w', content='{"1008611": ["This_is_an_example"]}')
-    if not os.path.exists(config_group_admin):
+    if not config_group_admin.exists():
         await mk('file', config_group_admin, 'w', content='{"su": "True"}')
-    if not os.path.exists(word_path):
+    if not word_path.exists():
         await mk('file', word_path, 'w', content='123456789\n')
-    if not os.path.exists(switcher_path):
+    if not switcher_path.exists():
         bot = nonebot.get_bot()
-        logger.info('创建开关配置文件,分群设置, 图片检测和违禁词检测默认关,其他默认开')
+        logger.info('创建开关配置文件,分群设置, 图片检测和违禁词检测,防撤回，广播，早晚安默认关,其他默认开')
         g_list = (await bot.get_group_list())
         switcher_dict = {}
         for group in g_list:
-            switcher_dict.update({str(group['group_id']): {'admin': True, 'requests': True,
-                                                           'wordcloud': True, 'auto_ban': False,
-                                                           'img_check': False, 'word_analyze': True}})
+            switchers = {}
+            for fn_name in admin_funcs:
+                switchers.update({fn_name: True})
+                if fn_name in ['img_check', 'auto_ban', 'group_msg', 'particular_e_notice', 'group_recall']:
+                    switchers.update({fn_name: False})
+            switcher_dict.update({str(group['group_id']): switchers})
         with open(switcher_path, 'w', encoding='utf-8') as swp:
             swp.write(f"{json.dumps(switcher_dict)}")
-            swp.close()
-    if not os.path.exists(limit_word_path):  # 要联网的都丢最后面去
-        if os.path.exists(config_path / '违禁词_简单.txt'):
+    if not limit_word_path.exists():  # 要联网的都丢最后面去
+        if (config_path / '违禁词_简单.txt').exists():
             with open(config_path / '违禁词_简单.txt', 'r', encoding='utf-8') as f:
                 content = f.read()
             with open(limit_word_path, 'w', encoding='utf-8') as f:
                 f.write(content)
-            os.remove(config_path / '违禁词_简单.txt')
+            (config_path / '违禁词_简单.txt').unlink()
         else:
             await mk('file', limit_word_path, 'w',
                      url='https://fastly.jsdelivr.net/gh/yzyyz1387/nwafu/f_words/f_word_easy', dec='简单违禁词词库')
-    if not os.path.exists(ttf_name):
+    if not ttf_name.exists():
         await mk('file', ttf_name, 'wb', url='https://fastly.jsdelivr.net/gh/yzyyz1387/blogimages/msyhblod.ttf',
                  dec='资源字体')
     logger.info('Admin 插件 初始化检测完成')
@@ -330,7 +333,7 @@ def image_moderation(img):
         req = models.ImageModerationRequest()
         params = (
             {'BizType': 'group_recall', 'FileUrl': img}
-            if type(img) == str
+            if type(img) is str
             else {'BizType': 'group_recall', 'FileContent': bytes_to_base64(img)}
         )
         req.from_json_string(json.dumps(params))
@@ -356,22 +359,20 @@ def bytes_to_base64(data):
     return base64.b64encode(data).decode('utf-8')
 
 
-async def load(path) -> Optional[dict]:
+def json_load(path) -> Optional[dict]:
     """
     加载json文件
     :return: Optional[dict]
     """
     try:
         with open(path, mode='r', encoding='utf-8') as f:
-            contents_ = f.read()
-            contents = json.loads(contents_)
-            f.close()
+            contents = json.load(f)
             return contents
     except FileNotFoundError:
         return None
 
 
-async def upload(path, dict_content) -> None:
+def json_upload(path, dict_content) -> None:
     """
     更新json文件
     :param path: 路径
@@ -379,35 +380,6 @@ async def upload(path, dict_content) -> None:
     """
     with open(path, mode='w', encoding='utf-8') as c:
         c.write(json.dumps(dict_content, ensure_ascii=False, indent=2))
-        c.close()
-
-
-async def check_func_status(func_name: str, gid: str) -> bool:
-    """
-    检查某个群的某个功能是否开启
-    :param func_name: 功能名
-    :param gid: 群号
-    :return: bool
-    """
-    funcs_status = (await load(switcher_path))
-    if funcs_status is None:
-        raise FileNotFoundError(switcher_path)
-    try:
-        if funcs_status[gid][func_name]:
-            return True
-        else:
-            return False
-    except KeyError:  # 新加入的群
-        logger.info(
-            f"本群({gid})尚未初始化！将自动初始化：关闭所有开关且设置过滤级别为简单。\n\n请重新发送指令继续之前的操作")
-        if cb_notice:
-            # await nonebot.get_bot().send_group_msg(group_id = gid, message = '本群尚未初始化，将自动初始化：开启所有开关且设置过滤级别为简单。\n\n'
-            #                                                              '请重新发送指令继续之前的操作')
-            logger.info('错误发生在 utils.py line 398')
-        funcs_status.update({str(gid): {'admin': True, 'requests': True, 'wordcloud': True,
-                                        'auto_ban': True, 'img_check': True, 'word_analyze': True}})
-        await upload(switcher_path, funcs_status)
-        return False  # 直接返回 false
 
 
 async def del_txt_line(path: Path, matcher: Matcher, event: GroupMessageEvent, args: Message, dec: str,
@@ -419,6 +391,7 @@ async def del_txt_line(path: Path, matcher: Matcher, event: GroupMessageEvent, a
     :param event: 事件
     :param args: 文本
     :param dec: 描述
+    :param group: 是否为群聊
     """
     gid = str(event.group_id)
     logger.info(args)
@@ -429,7 +402,6 @@ async def del_txt_line(path: Path, matcher: Matcher, event: GroupMessageEvent, a
         try:
             with open(this_path, mode='r+', encoding='utf-8') as c:
                 is_saved = c.read().split("\n")
-                c.close()
             with open(this_path, mode='w', encoding='utf-8') as c:
                 success_del = []
                 already_del = []
@@ -461,6 +433,7 @@ async def add_txt_line(path: Path, matcher: Matcher, event: GroupMessageEvent, a
     :param event: 事件
     :param args: 文本
     :param dec: 描述
+    :param group: 是否为群聊
     """
     gid = str(event.group_id)
     logger.info(args)
@@ -506,6 +479,7 @@ async def get_txt_line(path: Path, matcher: Matcher, event: GroupMessageEvent, a
     :param event: 事件
     :param args: 文本
     :param dec: 描述
+    :param group: 是否为群聊
     """
     gid = str(event.group_id)
     try:
@@ -539,7 +513,7 @@ async def change_s_title(bot: Bot, matcher: Matcher, gid: int, uid: int, s_title
             special_title=s_title,
             duration=-1,
         )
-        log_fi(matcher, f"头衔操作成功:{s_title}")
+        await log_fi(matcher, f"头衔操作成功:{s_title}")
     except ActionFailed:
         logger.info('权限不足')
 
@@ -565,12 +539,12 @@ async def get_user_violation(gid: int, uid: int, label: str, content: str, add_:
         await vio_level_init(path_user, uid, this_time, label, content)
         return 0
     try:
-        info = (await load(path_user))
+        info = json_load(path_user)
         level = info[uid]['level']
         if add_:
             info[uid]['level'] += 1
         info[uid]['info'][this_time] = [label, content]
-        await upload(path_user, info)
+        json_upload(path_user, info)
         if level >= 7:
             return 7
         else:
@@ -587,7 +561,6 @@ async def get_user_violation(gid: int, uid: int, label: str, content: str, add_:
 async def vio_level_init(path_user, uid, this_time, label, content) -> None:
     with open(path_user, mode='w', encoding='utf-8') as c:
         c.write(json.dumps({uid: {'level': 0, 'info': {this_time: [label, content]}}}, ensure_ascii=False))
-        c.close()
 
 
 async def error_log(gid: int, time: str, matcher: Matcher, err: str) -> None:
@@ -595,12 +568,12 @@ async def error_log(gid: int, time: str, matcher: Matcher, err: str) -> None:
     if not os.path.exists(error_path):
         await mk('dir', error_path, mode=None)
     if not os.path.exists(error_path / f"{str(gid)}.json"):
-        await upload(error_path / f"{str(gid)}.json", {str(gid): {time: [module, err]}})
+        json_upload(error_path / f"{str(gid)}.json", {str(gid): {time: [module, err]}})
     else:
         try:
-            info = (await load(error_path / f"{str(gid)}.json"))
+            info = json_load(error_path / f"{str(gid)}.json")
             info[str(gid)][time] = [module, err]
-            await upload(error_path / f"{str(gid)}.json", info)
+            json_upload(error_path / f"{str(gid)}.json", info)
         except Exception as e:
             logger.error(f"写入错误日志出错：{e}")
 
@@ -622,3 +595,4 @@ async def fi(cmd: Matcher, msg) -> None:
 async def log_fi(cmd: Matcher, msg, log: str = None, err=False) -> None:
     (logger.error if err else logger.info)(log if log else msg)
     await fi(cmd, msg)
+
